@@ -339,7 +339,7 @@ register struct obj	*sobj;
 	    }
 /*	    break;	/*NOTREACHED*/
 	case SCR_ENCHANT_WEAPON:
-		if(uwep && (uwep->olet == WEAPON_SYM || uwep->olet == PICK_AXE)
+		if(uwep && (uwep->olet == WEAPON_SYM || uwep->otyp == PICK_AXE)
 							&& confused) {
 		/* olet check added 10/25/86 GAN */
 			if(Blind)
@@ -476,17 +476,21 @@ register struct obj	*sobj;
 		    case MAGIC_LAMP:
 			if (sobj->cursed) stripspe(obj);
 			else if (sobj->blessed) {
-			    if (obj->spe == 1) pline(nothing_happens);
+			    if (obj->spe == 1 || obj->recharged)
+				pline(nothing_happens);
 			    else {
 				obj->spe = 1;
+				obj->recharged = 1;
 				p_glow1(obj);
 			    }
 			} else {
-			    if (obj->spe == 1) pline(nothing_happens);
+			    if (obj->spe == 1 || obj->recharged)
+				pline(nothing_happens);
 			    else {
 				n = rn2(2);
 				if (!n) {
 				    obj->spe = 1;
+				    obj->recharged = 1;
 				    p_glow1(obj);
 				} else pline(nothing_happens);
 			    }
@@ -1022,77 +1026,6 @@ register struct obj *atmp;
 	return(1);
 }
 
-/* the detections are pulled out so they can	*/
-/* also be used in the crystal ball routine	*/
-/* returns 1 if nothing was detected		*/
-/* returns 0 if something was detected		*/
-int
-trap_detect(sobj)
-register struct obj	*sobj;
-/* sobj is null if crystal ball, *scroll if gold detection scroll */
-{
-	register struct trap *ttmp;
-	register struct obj *obj;
-	register int door;
-	boolean found = FALSE;
-	coord cc;
-
-	for(ttmp = ftrap; ttmp; ttmp = ttmp->ntrap) {
-		if(ttmp->tx != u.ux || ttmp->ty != u.uy)
-			goto outtrapmap;
-		else found = TRUE;
-	}
-	for(obj = fobj; obj; obj = obj->nobj) {
-		if ((obj->otyp==LARGE_BOX || obj->otyp==CHEST) && obj->otrapped)
-			if (obj->ox != u.ux || obj->oy != u.uy)
-				goto outtrapmap;
-			else found = TRUE;
-	}
-	for(door=0; door<=doorindex; door++) {
-		cc = doors[door];
-		if (levl[cc.x][cc.y].doormask & D_TRAPPED)
-			if (cc.x != u.ux || cc.x != u.uy)
-				goto outtrapmap;
-			else found = TRUE;
-	}
-	if(!found) {
-		char buf[42];
-		Sprintf(buf, "Your %s stop itching.",
-			makeplural(body_part(TOE)));
-		strange_feeling(sobj,buf);
-		return(1);
-	}
-	/* traps exist, but only under me - no separate display required */
-	Your("%s itch.", makeplural(body_part(TOE)));
-	return(0);
-outtrapmap:
-	cls();
-#define SYMBOL (uchar)(Hallucination ? rndobjsym() : \
-		(sobj && sobj->cursed) ? GOLD_SYM : TRAP_SYM)
-#define AT Hallucination || (sobj && sobj->cursed) ? AT_OBJ : AT_MAP
-	for(ttmp = ftrap; ttmp; ttmp = ttmp->ntrap)
-		at(ttmp->tx, ttmp->ty, SYMBOL, AT);
-	for(obj = fobj; obj; obj = obj->nobj) {
-		if ((obj->otyp==LARGE_BOX || obj->otyp==CHEST) && obj->otrapped)
-			at(obj->ox, obj->oy, SYMBOL, AT);
-	}
-	for(door=0; door<=doorindex; door++) {
-		cc = doors[door];
-		if (levl[cc.x][cc.y].doormask & D_TRAPPED)
-			at(cc.x, cc.y, SYMBOL, AT);
-	}
-#undef SYMBOL
-#undef AT
-	prme();
-	if (sobj && sobj->cursed)
-		You("feel very greedy.");
-	else
-		You("feel entrapped.");
-	more();
-	docrt();
-	return(0);
-}
-
 int
 gold_detect(sobj)
 register struct obj	*sobj;
